=======
History
=======

0.0.1 (2019-09-26)
------------------

* First release on PyPI.

1.0.0 (2019-10-03)
------------------
    
* Remove Travis support for Python 3.5 / `Pull request #27 <https://github.com/glenjarvis/badgr-lite/pull/27>`_
* Update snowballstemmer to 2.0.0 / `Pull request #24 <https://github.com/glenjarvis/badgr-lite/pull/24>`_
* [Fixes: #25] Remove support for Python 3.5 / `Pull request #26 <https://github.com/glenjarvis/badgr-lite/pull/26>`_
* Update astroid to 2.3.1 / `Pull request #22 <https://github.com/glenjarvis/badgr-lite/pull/22>`_
* [Fixes #20] Upgrade tox to 3.14.0 / `Pull request #21 <https://github.com/glenjarvis/badgr-lite/pull/21>`_
* [Fixes #18] Fix README shields / `Pull request #19 <https://github.com/glenjarvis/badgr-lite/pull/19>`_

